@@ -29,8 +29,9 @@ from docutils.parsers.rst import Directive
 from sphinx.util.docfields import Field, GroupedField, TypedField
 from sphinx.util.nodes import make_refnode
 
+from sphinxcontrib.chapeldomain.chapel import ChapelLexer
 
-VERSION = '0.0.17'
+VERSION = '0.0.18'
 
 
 # regex for parsing proc, iter, class, record, etc.
@@ -1027,5 +1028,7 @@ class ChapelDomain(Domain):
 
 def setup(app):
     """Add Chapel domain to Sphinx app."""
+    # First add the in-house lexer to override the pygments one
+    app.add_lexer('chapel', ChapelLexer)
     app.add_config_value('chapeldomain_modindex_common_prefix', [], 'html')
     app.add_domain(ChapelDomain)
